@@ -2,7 +2,7 @@ from __future__ import absolute_import, division, unicode_literals
 
 from .. import cmds
 from .. import guicmds
-# from ..widgets import archive
+from ..widgets import archive
 from ..widgets import browse
 from ..widgets import compare
 from ..widgets import createbranch
@@ -79,11 +79,11 @@ COMMANDS = {
         'action': guicmds.export_patches,
         'icon': None
     },
-    # 'File::SaveAsTarZip': {
-    #     'title': 'Save As Tarball/Zip...',
-    #     'action': archive.save_archive,
-    #     'icon': 'file_zip'
-    # },
+    'File::SaveAsTarZip': {
+        'title': 'Save As Tarball/Zip...',
+        'action': archive.save_archive,
+        'icon': 'file_zip'
+    },
     # 'File::Preferences': {
     #     'title': 'Preferences',
     #     'action': prefs.preferences,
